/* 
 * Copyright (C) 2012 Laird Breyer
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Author:   Laird Breyer <laird@lbreyer.com>
 */

#include "annotations.h"

#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <string.h>

const char *annotations_default[] = {
  "",
  "user2",
  "user3",
  "user4",
  "user5",
  "user6",
  "user7",
  "user8",
};

bool_t create_annotations(annotations_t *a) {
  unsigned int i;
  if( a ) {
    for(i = 0; i < ANMAX; i++) {
      a->description[i] = strndup(annotations_default[i], ANLEN);
    }
    return TRUE;
  }
  return FALSE;
}

bool_t free_annotations(annotations_t *a) {
  unsigned int i;
  if( a ) {
    for(i = 0; i < ANMAX; i++) {
      free(a->description[i]);
    }
    return TRUE;
  }
  return FALSE;
}

const char *get_annotations(annotations_t *a, unsigned int i) {
  return (i < ANMAX) ? a->description[i] : "";
}

void set_annotations(annotations_t *a, unsigned int i, const byte_t *s) {
  if( (i < ANMAX) && s &&
      (!*s || strcmp((char*)s, get_annotations(a, i)) != 0) ) {
    free(a->description[i]);
    a->description[i] = strndup((char *)s, ANLEN);
  }
}
